@@ -1,8 +1,7 @@
 # et:ts=4
 # portextract.tcl
-# $Id: portextract.tcl 81270 2011-07-28 14:36:18Z afb@macports.org $
 #
-# Copyright (c) 2005, 2007-2011 The MacPorts Project
+# Copyright (c) 2005, 2007-2011, 2013 The MacPorts Project
 # Copyright (c) 2002 - 2003 Apple Inc.
 # Copyright (c) 2007 Markus W. Weissmann <mww@macports.org>
 # All rights reserved.
@@ -65,7 +64,7 @@ set_ui_prefix
 # Helper function for portextract.tcl that strips all tag names from a list
 # Used to clean ${distfiles} for setting the ${extract.only} default
 proc portextract::disttagclean {list} {
-    if {"$list" == ""} {
+    if {$list eq ""} {
         return $list
     }
     foreach name $list {
@@ -75,7 +74,7 @@ proc portextract::disttagclean {list} {
 }
 
 proc portextract::extract_start {args} {
-    global UI_PREFIX extract.dir extract.mkdir use_bzip2 use_lzma use_xz use_zip use_7z use_dmg
+    global UI_PREFIX extract.dir extract.mkdir use_bzip2 use_lzma use_xz use_zip use_7z use_lzip use_dmg
 
     ui_notice "$UI_PREFIX [format [msgcat::mc "Extracting %s"] [option subport]]"
 
@@ -90,7 +89,11 @@ proc portextract::extract_start {args} {
         set extract.dir ${worksrcpath}
     }
     if {[tbool use_bzip2]} {
-        option extract.cmd [findBinary bzip2 ${portutil::autoconf::bzip2_path}]
+        if {![catch {findBinary lbzip2} result]} {
+            option extract.cmd $result
+        } else {
+            option extract.cmd [findBinary bzip2 ${portutil::autoconf::bzip2_path}]
+        }
     } elseif {[tbool use_lzma]} {
         option extract.cmd [findBinary lzma ${portutil::autoconf::lzma_path}]
     } elseif {[tbool use_xz]} {
@@ -103,17 +106,21 @@ proc portextract::extract_start {args} {
         option extract.cmd [binaryInPath "7za"]
         option extract.pre_args x
         option extract.post_args ""
+    } elseif {[tbool use_lzip]} {
+        option extract.cmd [binaryInPath "lzip"]
+        option extract.pre_args "-dc"
+        #option extract.post_args ""
     } elseif {[tbool use_dmg]} {
         global distname extract.cmd
         set dmg_mount [mkdtemp "/tmp/mports.XXXXXXXX"]
         option extract.cmd [findBinary hdiutil ${portutil::autoconf::hdiutil_path}]
         option extract.pre_args attach
-        option extract.post_args "-private -readonly -nobrowse -mountpoint \\\"${dmg_mount}\\\" && [findBinary cp ${portutil::autoconf::cp_path}] -Rp \\\"${dmg_mount}\\\" \\\"${extract.dir}/${distname}\\\" && ${extract.cmd} detach \\\"${dmg_mount}\\\" && [findBinary rmdir ${portutil::autoconf::rmdir_path}] \\\"${dmg_mount}\\\""
+        option extract.post_args "-private -readonly -nobrowse -mountpoint \\\"${dmg_mount}\\\" && cd \\\"${dmg_mount}\\\" && [findBinary find ${portutil::autoconf::find_path}] . -depth -perm -+r -print0 | [findBinary cpio ${portutil::autoconf::cpio_path}] -0 -p -d -m -u \\\"${extract.dir}/${distname}\\\"; status=\$?; cd / && ${extract.cmd} detach \\\"${dmg_mount}\\\" && [findBinary rmdir ${portutil::autoconf::rmdir_path}] \\\"${dmg_mount}\\\"; exit \$status"
     }
 }
 
 proc portextract::extract_main {args} {
-    global UI_PREFIX filespath worksrcpath extract.dir usealtworkpath altprefix
+    global UI_PREFIX filespath worksrcpath extract.dir use_dmg
 
     if {![exists distfiles] && ![exists extract.only]} {
         # nothing to do
@@ -124,19 +131,26 @@ proc portextract::extract_main {args} {
         ui_info "$UI_PREFIX [format [msgcat::mc "Extracting %s"] $distfile]"
         if {[file exists $filespath/$distfile]} {
             option extract.args "'$filespath/$distfile'"
-        } elseif {![file exists "[option distpath]/$distfile"] && !$usealtworkpath && [file exists "${altprefix}[option distpath]/$distfile"]} {
-            option extract.args "'${altprefix}[option distpath]/$distfile'"
         } else {
             option extract.args "'[option distpath]/$distfile'"
         }
-        if {[catch {command_exec extract} result]} {
+
+        # If the MacPorts user does not have the privileges to mount a
+        # DMG then hdiutil will fail with this error:
+        #   hdiutil: attach failed - Device not configured
+        # So elevate back to root.
+        if {[tbool use_dmg]} {
+            elevateToRoot {extract dmg}
+        }
+        set code [catch {command_exec extract} result]
+        if {[tbool use_dmg]} {
+            dropPrivileges
+        }
+        if {$code} {
             return -code error "$result"
         }
 
-    # start gsoc08-privileges
-    chownAsRoot ${extract.dir}
-    # end gsoc08-privileges
-
+        chownAsRoot ${extract.dir}
     }
     return 0
 }
